(function(mod) {
  if (typeof exports == "object" && typeof module == "object") // CommonJS
    mod(require("../../lib/codemirror"), require("../../mode/askiascript/askiascript"));
  else if (typeof define == "function" && define.amd) // AMD
    define(["../../lib/codemirror", "../../mode/askiascript/askiascript"], mod);
  else // Plain browser env
    mod(CodeMirror);
})(function defineLexical(CodeMirror) {
  "use strict";

var askiaScript = CodeMirror.askiaScript;

askiaScript.extend(askiaScript.types, {
    "CALCVAR" : "calcvar",    
    "CALCVARRESPONSE" : "calcvarresponse",    
    "CALCVARRESPONSES" : "calcvarresponses",    
    "PORTFOLIO" : "portfolio",    
    "PORTFOLIOITEM" : "portfolioitem",    
    "PROFILE" : "profile",    
    "PROFILEITEM" : "profileitem",    
    "PROFILEQUESTION" : "profilequestion",    
    "SUBPOPULATION" : "subpopulation",    
    "TABDEF" : "tabdef",    
    "WEIGHTING" : "weighting"
});

askiaScript.extend(askiaScript.i18n, {
    "types" : {
        "calcvar" : "CalcVar",        
        "calcvarresponse" : "CalcVarResponse",        
        "calcvarresponses" : "CalcVarResponses",        
        "portfolio" : "Portfolio",        
        "portfolioitem" : "PortfolioItem",        
        "profile" : "Profile",        
        "profileitem" : "ProfileItem",        
        "profilequestion" : "ProfileQuestion",        
        "subpopulation" : "SubPopulation",        
        "tabdef" : "TabDef",        
        "weighting" : "Weighting"
    },    
    "core" : {
        "calcvar" : {
            "ns" : "autoanalyselanguage",            
            "desc" : "\tObject used to define a calculated variable or question",            
            "version" : "5.6.1.0"
        },        
        "calcvarresponse" : {
            "ns" : "autoanalyselanguage",            
            "desc" : "array of responses for object CalcVar",            
            "version" : "5.6.1.0"
        },        
        "calcvarresponses" : {
            "ns" : "autoanalyselanguage",            
            "desc" : "array of CalcVarResponse",            
            "version" : "5.6.1.0"
        },        
        "portfolio" : {
            "ns" : "autoanalyselanguage",            
            "desc" : "\tObject used to define a portfolio or a clone",            
            "version" : "5.5.2.0"
        },        
        "portfolioitem" : {
            "ns" : "autoanalyselanguage",            
            "desc" : "\tObject used to define a portfolioItem : a chapter or a tabdef",            
            "version" : "5.5.2.0"
        },        
        "profile" : {
            "ns" : "autoanalyselanguage",            
            "desc" : "\tObject used to define a profile, that is a list of profile questions",            
            "version" : "5.5.2.0"
        },        
        "profileitem" : {
            "ns" : "autoanalyselanguage",            
            "desc" : "\tObject used to define a profile item, that is a response or a group of responses (or a calculated response)",            
            "version" : "5.5.3.0"
        },        
        "profilequestion" : {
            "ns" : "autoanalyselanguage",            
            "desc" : "\tObject used to define a profile question, that is a list of responses or grouped responses linked to a question",            
            "version" : "5.5.3.0"
        },        
        "subpopulation" : {
            "ns" : "autoanalyselanguage",            
            "desc" : "\tObject used to define a sub-population, that is a list of interviews (sometimes called a filter)",            
            "version" : "5.5.3.0"
        },        
        "tabdef" : {
            "ns" : "autoanalyselanguage",            
            "desc" : "\tObject used to define the definition of a cross-tab",            
            "version" : "5.5.2.0"
        },        
        "weighting" : {
            "ns" : "autoanalyselanguage",            
            "desc" : "\tObject used to define a weighting, that is a factor attributed to each interview to correct sampling error",            
            "version" : "5.6.1.0"
        }
    }
}, true);

askiaScript.extend(askiaScript.lexical, {
    "namespaces" : {
        "autoanalyselanguage" : {
            "name" : "AutoAnalyseLanguage",            
            "ns" : "autoanalyselanguage",            
            "dependencies" : [
                "aggregatedlanguage"
            ]
        }
    },    
    "builtin" : [
        {
            "name" : "GetCommandParameters",            
            "ns" : "autoanalyselanguage",            
            "base" : "function",            
            "type" : "stringarray",            
            "desc" : "\tGets the list of additional parameters passed in the command line with the '/parameters' switch",            
            "examples" : [
                "\t. ' Run Analyse from the command line with the switch: /parameters:\"1,abc,def\"",                
                "\tDim arrParams as Stringarray",                
                "\tarrParams = GetCommandParameters() ' now contains [\"1\",\"abc\",\"def\"]",                
                "\tfor i = 1 to arrParams.Count",                
                "\t\t  ...",                
                "\tNext i"
            ],            
            "version" : "5.6.1.0"
        }
    ],    
    "members" : {
        "profilequestion" : [
            {
                "name" : "Add",                
                "ns" : "autoanalyselanguage",                
                "base" : "method",                
                "type" : "profilequestion",                
                "args" : [
                    {
                        "name" : "Item",                        
                        "type" : "profileitem",                        
                        "desc" : "Adds a portfolio item"
                    },                    
                    {
                        "name" : "Parent",                        
                        "type" : "profileitem",                        
                        "desc" : "As a child of this item",                        
                        "opt" : true
                    },                    
                    {
                        "name" : "After",                        
                        "type" : "profileitem",                        
                        "desc" : "After this item",                        
                        "opt" : true
                    }
                ],                
                "desc" : "\tAdds a profile item to a profile question",                
                "examples" : [
                    "\tDim myProfile as Profile",                    
                    "\tDim myProfileQuestion as ProfileQuestion",                    
                    "\tmyProfileQuestion.Question = Gender",                    
                    "\tmyProfileQuestion.DeleteAll()",                    
                    "\tDim myGroup as ProfileItem",                    
                    "\tmyGroup.Caption = \"Male + Female\"",                    
                    "\tmyGroup.Type = 1",                    
                    "\tmyProfileQuestion.Add(myGroup)",                    
                    "",                    
                    "\tDim myResponse1 as ProfileItem",                    
                    "\tmyResponse1.Type = 0",                    
                    "\tmyResponse1.Response = 1",                    
                    "\tmyProfileQuestion.Add(myResponse1, myGroup)",                    
                    "",                    
                    "\tDim myResponse2 as ProfileItem",                    
                    "\tmyResponse2.Type = 0",                    
                    "\tmyResponse2.Response = 2",                    
                    "\tmyProfileQuestion.Add(myResponse2, myGroup, myResponse1)",                    
                    "",                    
                    "\tmyProfile.Add(myProfileQuestion)"
                ],                
                "version" : "5.5.3.0"
            },            
            {
                "name" : "AllowNumericCalc",                
                "ns" : "autoanalyselanguage",                
                "base" : "property",                
                "type" : "boolean",                
                "desc" : "\tAllows the numeric calculations (mean. std dev, etc...) to be done on a closed question",                
                "examples" : [
                    "\tDim q1 As ProfileQuestion",                    
                    "\tq1.AllowNumericCalc = True"
                ],                
                "version" : "5.6.1.0"
            },            
            {
                "name" : "Clear",                
                "ns" : "autoanalyselanguage",                
                "base" : "method",                
                "type" : "profilequestion",                
                "desc" : "\tDeletes all items of a profile question",                
                "examples" : [
                    "\tDim myProfileQuestion as ProfileQuestion",                    
                    "\tmyProfileQuestion.Question = Gender",                    
                    "\tmyProfileQuestion.Clear()"
                ],                
                "version" : "5.5.3.0"
            },            
            {
                "name" : "CreateBands",                
                "ns" : "autoanalyselanguage",                
                "base" : "method",                
                "type" : "profilequestion",                
                "args" : [
                    {
                        "name" : "Interval",                        
                        "type" : "number",                        
                        "desc" : "size"
                    }
                ],                
                "desc" : "\tBreaks a numeric question into intervals which will have the same size",                
                "examples" : [
                    "\tDim myTab as CrossTab",                    
                    "\tDim myQuestion As ProfileQuestion",                    
                    "\tmyQuestion.Question = Age",                    
                    "\tmyQuestion.CreateBrands(10,18,100)",                    
                    "\tmyTab.Rows.Add(myQuestion)"
                ],                
                "version" : "5.6.0.0"
            },            
            {
                "name" : "CreatePercentiles",                
                "ns" : "autoanalyselanguage",                
                "base" : "method",                
                "type" : "profilequestion",                
                "args" : [
                    {
                        "name" : "Number",                        
                        "type" : "number",                        
                        "desc" : "of intervals"
                    }
                ],                
                "desc" : "\tBreaks a numeric question into intervals which will have (roughly) the same counts",                
                "examples" : [
                    "\tDim myTab as CrossTab",                    
                    "\tDim myQuestion As ProfileQuestion",                    
                    "\tmyQuestion.Question = Department",                    
                    "\tmyQuestion.CreatePercentiles(4)",                    
                    "\tmyTab.Rows.Add(myQuestion)"
                ],                
                "version" : "5.6.0.0"
            },            
            {
                "name" : "FindAllValues",                
                "ns" : "autoanalyselanguage",                
                "base" : "method",                
                "type" : "profilequestion",                
                "desc" : "\tFinds all the values of a numeric question and closes down the quetsion",                
                "examples" : [
                    "\tDim myTab as CrossTab",                    
                    "\tDim myQuestion As ProfileQuestion",                    
                    "\tmyQuestion.Question = Department",                    
                    "\tmyQuestion.FindAllValues()",                    
                    "\tmyTab.Rows.Add(myQuestion)"
                ],                
                "version" : "5.6.0.0"
            },            
            {
                "name" : "NumericAggregation",                
                "ns" : "autoanalyselanguage",                
                "base" : "property",                
                "type" : "number",                
                "desc" : [
                    "\tIndicates how numeric questions are aggregated across levels",                    
                    "\tSum: 0 (default)",                    
                    "\tMinimum: 1",                    
                    "\tMaximum: 2",                    
                    "\tNumber of response: 3",                    
                    "\tMean: 4",                    
                    "\tMedian: 5",                    
                    "\tStandard deviation: 6",                    
                    "\tVariance: 7",                    
                    "\tStandard deviation estimator: 8",                    
                    "\tSum or zero: 9"
                ],                
                "examples" : [
                    "\tDim q1 As ProfileQuestion",                    
                    "\tq1.NumericAggregation = 4"
                ],                
                "version" : "5.6.1.0"
            },            
            {
                "name" : "ProfileItems",                
                "ns" : "autoanalyselanguage",                
                "base" : "property",                
                "type" : "profileitems",                
                "desc" : "\tReturns an array of profile items",                
                "examples" : "\tPortfolio.Items[1].TabDef.Rows.ProfileQuestions[1].ProfileItems[1]",                
                "version" : "5.6.1.0"
            },            
            {
                "name" : "Question",                
                "ns" : "autoanalyselanguage",                
                "base" : "property",                
                "type" : "question",                
                "desc" : "\tSets or returns the question for that profile question",                
                "examples" : [
                    "\tDim myQuestion as ProfileQuestion",                    
                    "\tmyQuestion.Question = Gender"
                ],                
                "version" : "5.5.3.0"
            },            
            {
                "name" : "SetSubPopulation",                
                "ns" : "autoanalyselanguage",                
                "base" : "method",                
                "type" : "profilequestion",                
                "args" : [
                    {
                        "name" : "Name",                        
                        "type" : "string"
                    }
                ],                
                "desc" : "\tSets the sub-population by name (if empty all interviews are selected)",                
                "examples" : [
                    "\tDim Q1 as ProfileQuestion",                    
                    "\tQ1.SetSubPopulation(\"Males\")"
                ],                
                "version" : "5.6.0.0"
            },            
            {
                "name" : "SetSubPopulation",                
                "ns" : "autoanalyselanguage",                
                "base" : "method",                
                "type" : "profilequestion",                
                "args" : [
                    {
                        "name" : "SP",                        
                        "type" : "subpopulation"
                    }
                ],                
                "desc" : "\tSets the sub-population by object (if the SP is not saved, then the object is empty)",                
                "examples" : [
                    "\tDim Q2 as ProfileQuestion",                    
                    "\tDim Sp as SubPopulation",                    
                    "\tQ2.SetSubPopulation(Sp)"
                ],                
                "version" : "5.6.0.0"
            },            
            {
                "name" : "SetUniverse",                
                "ns" : "autoanalyselanguage",                
                "base" : "method",                
                "type" : "profilequestion",                
                "args" : [
                    {
                        "name" : "Name",                        
                        "type" : "string"
                    }
                ],                
                "desc" : "\tSets the universe by name (if empty all interviews are selected)",                
                "examples" : [
                    "\tDim Q1 as ProfileQuestion",                    
                    "\tQ1.SetUniverse(\"Males\")"
                ],                
                "version" : "5.6.0.0"
            },            
            {
                "name" : "SetUniverse",                
                "ns" : "autoanalyselanguage",                
                "base" : "method",                
                "type" : "profilequestion",                
                "args" : [
                    {
                        "name" : "UniverseID",                        
                        "type" : "number"
                    }
                ],                
                "desc" : [
                    "\tSets the universe by specifiying its id",                    
                    "\tHere are the preset universe ids",                    
                    "\tSP_ALLINTERVIEWS\t\t\t\t\t-1",                    
                    "\tUNI_SELECTED_RESPONSES\t\t\t\t-2",                    
                    "\tUNI_QUESTION_BASE\t\t\t\t\t-3",                    
                    "\tUNI_ANSWERING_FREQUENCY\t\t\t\t-4",                    
                    "\tUNI_CURRENT_SUBPOPULATION\t\t\t-5",                    
                    "\tUNI_UNFILTERED_SELECTED_RESPONSE\t-6",                    
                    "\tUNI_UNFILTERED_QUESTION_BASE\t\t-7",                    
                    "\tUNI_UNFILTERED_ANSWERING_FREQUENCY\t-8",                    
                    "\tSP_NO_INTERVIEW\t\t\t\t\t\t-9",                    
                    "\tUNI_QUESTION_TABLE_BASE\t\t\t\t-11",                    
                    "\tUNI_ALL_INTERVIEWS_TABLE\t\t\t-12"
                ],                
                "examples" : [
                    "\tDim Q1 as ProfileQuestion",                    
                    "\tQ1.SetUniverse(-2)"
                ],                
                "version" : "5.6.0.0"
            },            
            {
                "name" : "SetWeighting",                
                "ns" : "autoanalyselanguage",                
                "base" : "method",                
                "type" : "profilequestion",                
                "args" : [
                    {
                        "name" : "Name",                        
                        "type" : "string"
                    }
                ],                
                "desc" : "\tSets the weighing by name (if empty \"No weighting\" is selected, pass \"Default\" to reset to the default value)",                
                "examples" : [
                    "\tDim Q1 as ProfileQuestion",                    
                    "\tQ1.SetWeighting(\"NatRep\")"
                ],                
                "version" : "5.6.1.0"
            },            
            {
                "name" : "SetWeighting",                
                "ns" : "autoanalyselanguage",                
                "base" : "method",                
                "type" : "profilequestion",                
                "args" : [
                    {
                        "name" : "Weight",                        
                        "type" : "weighting"
                    }
                ],                
                "desc" : "\tSets the weighting by object (if the weighting is not saved, \"No weighting\" is selected)",                
                "examples" : [
                    "\tDim Q2 as ProfileQuestion",                    
                    "\tDim W1 as Weighting",                    
                    "\tQ2.SetWeighting(W1)"
                ],                
                "version" : "5.6.1.0"
            }
        ],        
        "profileitem" : [
            {
                "name" : "Caption",                
                "ns" : "autoanalyselanguage",                
                "base" : "property",                
                "type" : "string",                
                "desc" : "\tSets or returns the caption for a response",                
                "examples" : [
                    "\tdim myGroup As ProfileItem",                    
                    "\tmyGroup.Caption =\"Total\""
                ],                
                "version" : "5.5.3.0"
            },            
            {
                "name" : "Factor",                
                "ns" : "autoanalyselanguage",                
                "base" : "property",                
                "type" : "number",                
                "desc" : "\tSets the value used for numeric calculation for a closed response",                
                "examples" : [
                    "\tDim myItem As ProfileItem",                    
                    "\tmyItem.Factor = 3.14"
                ],                
                "version" : "5.6.1.0"
            },            
            {
                "name" : "Response",                
                "ns" : "autoanalyselanguage",                
                "base" : "property",                
                "type" : "number",                
                "desc" : "\tSets or returns the response for that item",                
                "examples" : [
                    "\tDim myItem as ProfileItem",                    
                    "\tmyItem.Response = 1 "
                ],                
                "version" : "5.5.3.0"
            },            
            {
                "name" : "Script",                
                "ns" : "autoanalyselanguage",                
                "base" : "property",                
                "type" : "string",                
                "desc" : "\tSets or returns the script of a calculated response",                
                "examples" : [
                    "\tdim myCalc As ProfileItem",                    
                    "\tmyCalc.Caption =\"Calc\"",                    
                    "\tmyCalc.Script =\"{1} - {2}\""
                ],                
                "version" : "5.5.3.0"
            },            
            {
                "name" : "Selected",                
                "ns" : "autoanalyselanguage",                
                "base" : "property",                
                "type" : "boolean",                
                "desc" : "\tSets or returns if a response is visible in the tab def (Group and hide)",                
                "examples" : [
                    "\tdim myCalc As ProfileItem",                    
                    "\tmyCalc.Selected = False"
                ],                
                "version" : "5.5.3.0"
            },            
            {
                "name" : "SetSubPopulation",                
                "ns" : "autoanalyselanguage",                
                "base" : "method",                
                "type" : "profileitem",                
                "args" : [
                    {
                        "name" : "Name",                        
                        "type" : "string"
                    }
                ],                
                "desc" : "\tSets the sub-population by name (if empty all interviews are selected)",                
                "examples" : [
                    "\tDim R1 as ProfileItem",                    
                    "\tR1.SetSubPopulation(\"Males\")"
                ],                
                "version" : "5.6.0.0"
            },            
            {
                "name" : "SetSubPopulation",                
                "ns" : "autoanalyselanguage",                
                "base" : "method",                
                "type" : "profileitem",                
                "args" : [
                    {
                        "name" : "SP",                        
                        "type" : "subpopulation"
                    }
                ],                
                "desc" : "\tSets the sub-population by object (if the SP is not saved, then the sub-population is \"all interviews\")",                
                "examples" : [
                    "\tDim R2 as ProfileItem",                    
                    "\tDim Sp as SubPopulation",                    
                    "\tR2.SetSubPopulation(Sp)"
                ],                
                "version" : "5.6.0.0"
            },            
            {
                "name" : "SetUniverse",                
                "ns" : "autoanalyselanguage",                
                "base" : "method",                
                "type" : "profileitem",                
                "args" : [
                    {
                        "name" : "Name",                        
                        "type" : "string"
                    }
                ],                
                "desc" : "\tSets the universe by name (if empty all interviews are selected)",                
                "examples" : [
                    "\tDim R1 as ProfileItem",                    
                    "\tR1.SetUniverse(\"Males\")"
                ],                
                "version" : "5.6.0.0"
            },            
            {
                "name" : "SetUniverse",                
                "ns" : "autoanalyselanguage",                
                "base" : "method",                
                "type" : "profileitem",                
                "args" : [
                    {
                        "name" : "UniverseID",                        
                        "type" : "number"
                    }
                ],                
                "desc" : [
                    "\tSets the universe by specifiying its id",                    
                    "\tHere are the preset universe ids",                    
                    "\tSP_ALLINTERVIEWS\t\t\t\t\t-1",                    
                    "\tUNI_SELECTED_RESPONSES\t\t\t\t-2",                    
                    "\tUNI_QUESTION_BASE\t\t\t\t\t-3",                    
                    "\tUNI_ANSWERING_FREQUENCY\t\t\t\t-4",                    
                    "\tUNI_CURRENT_SUBPOPULATION\t\t\t-5",                    
                    "\tUNI_UNFILTERED_SELECTED_RESPONSE\t-6",                    
                    "\tUNI_UNFILTERED_QUESTION_BASE\t\t-7",                    
                    "\tUNI_UNFILTERED_ANSWERING_FREQUENCY\t-8",                    
                    "\tSP_NO_INTERVIEW\t\t\t\t\t\t-9",                    
                    "\tUNI_QUESTION_TABLE_BASE\t\t\t\t-11",                    
                    "\tUNI_ALL_INTERVIEWS_TABLE\t\t\t-12"
                ],                
                "examples" : [
                    "\tDim R1 as ProfileItem",                    
                    "\tR1.SetUniverse(-2)"
                ],                
                "version" : "5.6.0.0"
            },            
            {
                "name" : "SetWeighting",                
                "ns" : "autoanalyselanguage",                
                "base" : "method",                
                "type" : "profileitem",                
                "args" : [
                    {
                        "name" : "Name",                        
                        "type" : "string"
                    }
                ],                
                "desc" : "\tSets the weighing by name (if empty \"No weighting\" is selected, pass \"Default\" to reset to the default value)",                
                "examples" : [
                    "\tDim R1 as ProfileItem",                    
                    "\tR1.SetWeighting(\"NatRep\")"
                ],                
                "version" : "5.6.1.0"
            },            
            {
                "name" : "SetWeighting",                
                "ns" : "autoanalyselanguage",                
                "base" : "method",                
                "type" : "profileitem",                
                "args" : [
                    {
                        "name" : "Weight",                        
                        "type" : "weighting"
                    }
                ],                
                "desc" : "\tSets the weighting by object (if the weighting is not saved, \"No weighting\" is selected)",                
                "examples" : [
                    "\tDim R2 as ProfileItem",                    
                    "\tDim Weight as Weighting",                    
                    "\tR2.SetWeighting(Weight)"
                ],                
                "version" : "5.6.1.0"
            },            
            {
                "name" : "Type",                
                "ns" : "autoanalyselanguage",                
                "base" : "property",                
                "type" : "number",                
                "desc" : [
                    "\tSets or returns the type of a portfolio item",                    
                    "\t0 => response ",                    
                    "\t1 => group",                    
                    "\t2 => Calculate item",                    
                    "\t3 => Interval"
                ],                
                "examples" : [
                    "\tdim myGroup As ProfileItem",                    
                    "\tmyGroup.Caption = \"Total\"",                    
                    "\tmyGroup.Type = 1 "
                ],                
                "version" : "5.5.3.0"
            }
        ],        
        "weighting" : [
            {
                "name" : "Description",                
                "ns" : "autoanalyselanguage",                
                "base" : "property",                
                "type" : "string",                
                "desc" : "\tReturns the description of a weighting",                
                "examples" : [
                    "\tmyWeighting.Name =\"NatRep\"",                    
                    "\tmyWeighting.Description =\"Weights according to national representativity\""
                ],                
                "version" : "5.6.1.0"
            },            
            {
                "name" : "Efficiency",                
                "ns" : "autoanalyselanguage",                
                "base" : "property",                
                "type" : "number",                
                "desc" : "\tReturns the calculation of the efficiency. It's only available once the Run method has been called",                
                "examples" : [
                    "\tDim myWeight As WWeighting",                    
                    "\tmyWeight.Run()",                    
                    "\tDim dEff = myWeight.Efficiency "
                ],                
                "version" : "5.6.1.0"
            },            
            {
                "name" : "InitialWeight",                
                "ns" : "autoanalyselanguage",                
                "base" : "property",                
                "type" : "question",                
                "desc" : "\tSets or returns the inital weights. This can be used if you want to define weights from an existing question",                
                "examples" : [
                    "\tDim myWt as Weighting",                    
                    "\tmyWt.Name =\"NatRep\"",                    
                    "\tmyWt.InitialWeight = q3",                    
                    "\tDim res = myWt.Save()"
                ],                
                "version" : "5.6.1.0"
            },            
            {
                "name" : "Name",                
                "ns" : "autoanalyselanguage",                
                "base" : "property",                
                "type" : "string",                
                "desc" : "\tSets or returns the name of a weighting",                
                "examples" : "\tmyWeighing.Name =\"NatRep\"",                
                "version" : "5.6.1.0"
            },            
            {
                "name" : "Parse",                
                "ns" : "autoanalyselanguage",                
                "base" : "method",                
                "type" : "methodresult",                
                "args" : [
                    {
                        "name" : "JSON",                        
                        "type" : "variant",                        
                        "desc" : "object defining the weighting"
                    }
                ],                
                "desc" : "\tSets the weights with a dictionary or a direct JSON call",                
                "examples" : [
                    "\tDim myWt as Weighting",                    
                    "\tmyWt.Name =\"NatRep\"",                    
                    "\tDim res = myWt.Parse(@{",                    
                    "\t\t\t\"desc\": \"\",",                    
                    "\t\t\t\"level\": \"\",",                    
                    "\t\t\t\"options\": {",                    
                    "\t\t\t\t\"accuracy\": 10,",                    
                    "\t\t\t\t\"countsForMultiple\": true,",                    
                    "\t\t\t\t\"iterationPerQuestion\": 30,",                    
                    "\t\t\t\t\"maxWeight\": 5.0,",                    
                    "\t\t\t\t\"meanType\": 0,",                    
                    "\t\t\t\t\"minWeight\": 0.0,",                    
                    "\t\t\t\t\"runQuestionsInLevel\": true,",                    
                    "\t\t\t\t\"runWavesIndependently\": false",                    
                    "\t\t\t},",                    
                    "\t\t\t\"questions\": [",                    
                    "\t\t\t\t{",                    
                    "\t\t\t\t\t\"key\": \"10@@0\",",                    
                    "\t\t\t\t\t\"shortcut\": \"i1. Gender\",",                    
                    "\t\t\t\t\t\"responses\": [",                    
                    "\t\t\t\t\t\t{",                    
                    "\t\t\t\t\t\t\t\"entryCode\": \"1\",",                    
                    "\t\t\t\t\t\t\t\"target\": 50.0",                    
                    "\t\t\t\t\t\t},",                    
                    "\t\t\t\t\t\t{",                    
                    "\t\t\t\t\t\t\t\"entryCode\": \"2\",",                    
                    "\t\t\t\t\t\t\t\"target\": 50.0",                    
                    "\t\t\t\t\t\t},",                    
                    "\t\t\t\t\t\t{",                    
                    "\t\t\t\t\t\t\t\"entryCode\": \"-2\",",                    
                    "\t\t\t\t\t\t\t\"target\": 0.0",                    
                    "\t\t\t\t\t\t}",                    
                    "\t\t\t\t\t]",                    
                    "\t\t\t\t}",                    
                    "\t\t\t],",                    
                    "\t\t\t\"weightingBase\": 0.0",                    
                    "\t\t})"
                ],                
                "version" : "5.6.1.0"
            },            
            {
                "name" : "Run",                
                "ns" : "autoanalyselanguage",                
                "base" : "method",                
                "type" : "methodresult",                
                "desc" : "\tRuns a weighting, creates the weighting report and fills the efficieny parameter",                
                "examples" : [
                    "\tDim myWt as Weighting",                    
                    "\tmyWt.Name =\"NatRep\"",                    
                    "\tmyWt.Description =\"National representative weights\"",                    
                    "\tDim res = myWt.Run()",                    
                    "\treturn res.Success"
                ],                
                "version" : "5.6.1.0"
            },            
            {
                "name" : "Save",                
                "ns" : "autoanalyselanguage",                
                "base" : "method",                
                "type" : "methodresult",                
                "desc" : "\tSaves a weighting in the survey. If a weighting has the same name, it's being replaced by this one",                
                "examples" : [
                    "\tDim myWt as Weighting",                    
                    "\tmyWt.Name =\"NatRep\"",                    
                    "\tmyWt.Description =\"National representative weights\"",                    
                    "\tDim res = myWt.Save()",                    
                    "\treturn res.Success"
                ],                
                "version" : "5.6.1.0"
            },            
            {
                "name" : "SetSubPopulation",                
                "ns" : "autoanalyselanguage",                
                "base" : "method",                
                "type" : "weighting",                
                "args" : [
                    {
                        "name" : "Name",                        
                        "type" : "string"
                    }
                ],                
                "desc" : "\tSets the sub-population by name to a weighting",                
                "examples" : [
                    "\tDim R1 as Weighting",                    
                    "\tR1.SetSubPopulation(\"Males\")"
                ],                
                "version" : "6.5.0.0"
            },            
            {
                "name" : "SetSubPopulation",                
                "ns" : "autoanalyselanguage",                
                "base" : "method",                
                "type" : "weighting",                
                "args" : [
                    {
                        "name" : "SP",                        
                        "type" : "subpopulation"
                    }
                ],                
                "desc" : "\tSets the sub-population by object (if the SP is not saved, then the sub-population is \"all interviews\")",                
                "examples" : [
                    "\tDim R2 as Weighting",                    
                    "\tDim Sp as SubPopulation",                    
                    "\tR2.SetSubPopulation(Sp)"
                ],                
                "version" : "6.5.0.0"
            }
        ],        
        "profile" : [
            {
                "name" : "Add",                
                "ns" : "autoanalyselanguage",                
                "base" : "method",                
                "type" : "profile",                
                "args" : [
                    {
                        "name" : "QuestionProfiles",                        
                        "type" : "profile",                        
                        "desc" : "Adds questions"
                    }
                ],                
                "desc" : "\tAdds a profile to a another profile",                
                "examples" : [
                    "\tDim myTab as CrossTab",                    
                    "\tmyTab.Rows.Add(myProfile)"
                ],                
                "version" : "5.5.2.0"
            },            
            {
                "name" : "Add",                
                "ns" : "autoanalyselanguage",                
                "base" : "method",                
                "type" : "profile",                
                "args" : [
                    {
                        "name" : "Question",                        
                        "type" : "question"
                    }
                ],                
                "desc" : "\tAdds a question to a profile and selects the specified responses (if nothing specified all responses are selected)",                
                "examples" : [
                    "\tDim myTab as CrossTab",                    
                    "\tmyTab.Rows.Add(Gender)"
                ],                
                "version" : "5.5.2.0"
            },            
            {
                "name" : "Add",                
                "ns" : "autoanalyselanguage",                
                "base" : "method",                
                "type" : "profile",                
                "args" : [
                    {
                        "name" : "ProfileQuestion",                        
                        "type" : "profilequestion"
                    }
                ],                
                "desc" : "\tAdds a profile question to a profile",                
                "examples" : [
                    "\tDim myTab as CrossTab",                    
                    "\tDim myQuestion As ProfileQuestion",                    
                    "\tmyQuestion.Question = Gender",                    
                    "\tmyTab.Rows.Add(myQuestion)"
                ],                
                "version" : "5.5.3.0"
            },            
            {
                "name" : "Clear",                
                "ns" : "autoanalyselanguage",                
                "base" : "method",                
                "type" : "profile",                
                "desc" : "\tClears a profile from all the questions in it. It also resets its name",                
                "examples" : "\tresItem.TabDef.Rows.Clear()",                
                "version" : "5.5.2.0"
            },            
            {
                "name" : "Clone",                
                "ns" : "autoanalyselanguage",                
                "base" : "method",                
                "type" : "profile",                
                "args" : [
                    {
                        "name" : "SourceQuestion",                        
                        "type" : "question",                        
                        "desc" : "Question to be cloned according to the presentation held in the profile"
                    }
                ],                
                "desc" : "\tReturns a profile cloned with the question received as a parameter",                
                "examples" : "\tresItem.TabDef.Rows.Add ( ClosedPortfolio.Items[1].TabDef.Rows.Clone(currQuestion) )",                
                "version" : "5.5.2.0"
            },            
            {
                "name" : "Name",                
                "ns" : "autoanalyselanguage",                
                "base" : "property",                
                "type" : "string",                
                "desc" : "\tSets or returns the name of a profile",                
                "examples" : "\tmyProfile.Name =\"Demographics\"",                
                "version" : "5.6.1.0"
            },            
            {
                "name" : "ProfileQuestions",                
                "ns" : "autoanalyselanguage",                
                "base" : "property",                
                "type" : "profilequestions",                
                "desc" : "\tReturns an array of profile questions",                
                "examples" : "\tPortfolio.Items[1].TabDef.Rows.ProfileQuestions[1]",                
                "version" : "5.5.2.0"
            }
        ],        
        "question" : [
            {
                "name" : "SetTag",                
                "ns" : "autoanalyselanguage",                
                "base" : "method",                
                "type" : "question",                
                "args" : [
                    {
                        "name" : "NewTag",                        
                        "type" : "string"
                    }
                ],                
                "desc" : "\tSets a tag for a question. If the tag does not exist, it's created",                
                "examples" : [
                    "\t",                    
                    "\tGender.SetTag(\"Demographics\")"
                ],                
                "version" : "5.6.1.0"
            },            
            {
                "name" : "SetTag",                
                "ns" : "autoanalyselanguage",                
                "base" : "method",                
                "type" : "question",                
                "args" : [
                    {
                        "name" : "Tags",                        
                        "type" : "stringarray"
                    }
                ],                
                "desc" : "\tSets a series of tags for a question. If the tags do not exist, they are created",                
                "examples" : "\tGender.SetTag({\"Demographics\";\"Binary\"})",                
                "version" : "5.6.1.0"
            }
        ],        
        "subpopulation" : [
            {
                "name" : "Description",                
                "ns" : "autoanalyselanguage",                
                "base" : "property",                
                "type" : "string",                
                "desc" : "\tReturns the description of a sub-population",                
                "examples" : [
                    "\tSubPopulation.Name =\"All males\"",                    
                    "\tSubPopulation.Description =\"All males interviewed in this wave\""
                ],                
                "version" : "5.5.3.0"
            },            
            {
                "name" : "Name",                
                "ns" : "autoanalyselanguage",                
                "base" : "property",                
                "type" : "string",                
                "desc" : "\tSets or returns the name of a sub-population",                
                "examples" : "\tSubPopulation.Name =\"All males\"",                
                "version" : "5.5.3.0"
            },            
            {
                "name" : "Save",                
                "ns" : "autoanalyselanguage",                
                "base" : "method",                
                "type" : "methodresult",                
                "desc" : "\tSaves a sub-population in the survey. If a sub-population has the same name, it's being replaced by this one",                
                "examples" : [
                    "\tDim mySP as SubPopulation",                    
                    "\tmySP.Name =\"All males\"",                    
                    "\tmySP.Script =\"Gender has {1}\"",                    
                    "\tDim res = mySP.Save()",                    
                    "\treturn res.Success"
                ],                
                "version" : "5.5.3.0"
            },            
            {
                "name" : "Script",                
                "ns" : "autoanalyselanguage",                
                "base" : "property",                
                "type" : "string",                
                "desc" : "\tReturns the script of a sub-population",                
                "examples" : [
                    "\tSubPopulation.Name =\"All males\"",                    
                    "\tSubPopulation.Script =\"Gender has {1}\""
                ],                
                "version" : "5.5.3.0"
            }
        ],        
        "portfolioitem" : [
            {
                "name" : "SetTabDef",                
                "ns" : "autoanalyselanguage",                
                "base" : "method",                
                "type" : "portfolioitem",                
                "args" : [
                    {
                        "name" : "TabDef",                        
                        "type" : "tabdef"
                    }
                ],                
                "desc" : "\tSets the tabdef for a portfolio",                
                "examples" : [
                    "\tDim myPortfolio as Portfolio",                    
                    "\tmyPortfolio.Items[1].SetTabdef(NewTabDef)"
                ],                
                "version" : "5.5.2.0"
            },            
            {
                "name" : "SetTitle",                
                "ns" : "autoanalyselanguage",                
                "base" : "method",                
                "type" : "portfolioitem",                
                "args" : [
                    {
                        "name" : "Title",                        
                        "type" : "string"
                    }
                ],                
                "desc" : "\tSets the title for a portfolio",                
                "examples" : [
                    "\tDim myPortfolio as Portfolio",                    
                    "\tmyPortfolio.Items[1].SetTitle(\"Chapter 1\")"
                ],                
                "version" : "5.5.2.0"
            },            
            {
                "name" : "SetType",                
                "ns" : "autoanalyselanguage",                
                "base" : "method",                
                "type" : "portfolioitem",                
                "args" : [
                    {
                        "name" : "Type",                        
                        "type" : "number"
                    }
                ],                
                "desc" : [
                    "\tSets the type of a portfolio item",                    
                    "\t0: Chapter",                    
                    "\t1: cross-tab definition Tab",                    
                    "\t2: table of contents",                    
                    "\t3: external file (xls)"
                ],                
                "examples" : [
                    "\tDim myPortfolio as Portfolio",                    
                    "\tmyPortfolio.Items[1].SetType(1)"
                ],                
                "version" : "5.5.2.0"
            },            
            {
                "name" : "TabDef",                
                "ns" : "autoanalyselanguage",                
                "base" : "property",                
                "type" : "tabdef",                
                "desc" : "\tReturns the definition of a tab-definition",                
                "examples" : "\tPortfolio.Items[1].TabDef.Rows.AddQuestion(Gender)",                
                "version" : "5.5.2.0"
            },            
            {
                "name" : "Title",                
                "ns" : "autoanalyselanguage",                
                "base" : "property",                
                "type" : "string",                
                "desc" : "\tSets or returns the title of a portfolio item",                
                "examples" : [
                    "\tdim myAnalysis As PortfolioItem",                    
                    "\tmyAnalysis.Title = \"Cross-tabs\""
                ],                
                "version" : "5.6.0.0"
            },            
            {
                "name" : "Type",                
                "ns" : "autoanalyselanguage",                
                "base" : "property",                
                "type" : "number",                
                "desc" : [
                    "\tReturns the type of a portfolioItem",                    
                    "\t0: Chapter",                    
                    "\t1: cross-tab definition Tab",                    
                    "\t2: table of contents",                    
                    "\t3: external file (xls)"
                ],                
                "version" : "5.5.2.0"
            },            
            {
                "name" : "Visible",                
                "ns" : "autoanalyselanguage",                
                "base" : "property",                
                "type" : "boolean",                
                "desc" : "\tSets or returns the visibility of a portfolio item (usefull for table arithmerics and hiding intermediate results)",                
                "examples" : [
                    "\tdim myAnalysis As PortfolioItem",                    
                    "\tmyAnalysis.Visible = False"
                ],                
                "version" : "5.6.0.0"
            }
        ],        
        "tabdef" : [
            {
                "name" : "Columns",                
                "ns" : "autoanalyselanguage",                
                "base" : "property",                
                "type" : "profile",                
                "desc" : "\tReturns the profile defining the columns of a cross-tab",                
                "examples" : "\tPortfolio.Items[1].TabDef.Columns.AddQuestion(Gender)",                
                "version" : "5.5.2.0"
            },            
            {
                "name" : "Edges",                
                "ns" : "autoanalyselanguage",                
                "base" : "property",                
                "type" : "profile",                
                "desc" : "\tReturns the profile defining the edges of a cross-tab",                
                "examples" : "\tPortfolio.Items[1].TabDef.Edges.AddQuestion(Gender)",                
                "version" : "5.5.2.0"
            },            
            {
                "name" : "LeftHeader",                
                "ns" : "autoanalyselanguage",                
                "base" : "property",                
                "type" : "string",                
                "desc" : "\tIndicates the left header in the merge options of a tab-template",                
                "examples" : [
                    "\tDim myTemp As TabDef",                    
                    "\tmyTemp.LeftHeader = \"Some text\""
                ],                
                "version" : "5.6.1.0"
            },            
            {
                "name" : "Level",                
                "ns" : "autoanalyselanguage",                
                "base" : "property",                
                "type" : "string",                
                "desc" : "\tSets or returns the name of the level used in the TabDef. The level is identified by the shortcut of the level. If the string is empty, the level is \"Interviews\"",                
                "examples" : "\tmyTabDef.Level =\"PeopleInHouseHold\"",                
                "version" : "5.5.3.0"
            },            
            {
                "name" : "ReadTabStyle",                
                "ns" : "autoanalyselanguage",                
                "base" : "method",                
                "type" : "methodresult",                
                "args" : [
                    {
                        "name" : "indicates",                        
                        "type" : "string",                        
                        "desc" : "the name of the tab-template in the library"
                    }
                ],                
                "desc" : "\tReads a tab-style form the library",                
                "examples" : [
                    "\tDim myTabDef as TabDef",                    
                    "\tDim res = myTabDef.ReadTabStyle(\"Blue\")",                    
                    "\treturn res.Success"
                ],                
                "version" : "5.6.0.0"
            },            
            {
                "name" : "ReadTabTemplate",                
                "ns" : "autoanalyselanguage",                
                "base" : "method",                
                "type" : "methodresult",                
                "args" : [
                    {
                        "name" : "Path",                        
                        "type" : "string",                        
                        "desc" : "indicates the name of the tab-template in the library"
                    }
                ],                
                "desc" : "\tReads a tab-template form the library",                
                "examples" : [
                    "\tDim myTabDef as TabDef",                    
                    "\tDim res = myTabDef.ReadTabTemplate(\"Col-sig\")",                    
                    "\treturn res.Success"
                ],                
                "version" : "5.5.2.0"
            },            
            {
                "name" : "Rows",                
                "ns" : "autoanalyselanguage",                
                "base" : "property",                
                "type" : "profile",                
                "desc" : "\tReturns the profile defining the rows of a cross-tab",                
                "examples" : "\tPortfolio.Items[1].TabDef.Rows.AddQuestion(Gender)",                
                "version" : "5.5.2.0"
            },            
            {
                "name" : "SetSubPopulation",                
                "ns" : "autoanalyselanguage",                
                "base" : "method",                
                "type" : "tabdef",                
                "args" : [
                    {
                        "name" : "Name",                        
                        "type" : "string"
                    }
                ],                
                "desc" : "\tSets the sub-population by name (if empty all interviews are selected)",                
                "examples" : [
                    "\tDim TabDef1 as TabDef",                    
                    "\tTabDef1.SetSubPopulation(\"Males\")"
                ],                
                "version" : "5.5.3.0"
            },            
            {
                "name" : "SetSubPopulation",                
                "ns" : "autoanalyselanguage",                
                "base" : "method",                
                "type" : "tabdef",                
                "args" : [
                    {
                        "name" : "SP",                        
                        "type" : "subpopulation"
                    }
                ],                
                "desc" : "\tSets the sub-population by object (if the SP is not saved, then the object is empty)",                
                "examples" : [
                    "\tDim TabDef1 as TabDef",                    
                    "\tDim Sp as SubPopulation",                    
                    "\tTabDef1.SetSubPopulation(Sp)"
                ],                
                "version" : "5.5.3.0"
            },            
            {
                "name" : "SetUniverse",                
                "ns" : "autoanalyselanguage",                
                "base" : "method",                
                "type" : "tabdef",                
                "args" : [
                    {
                        "name" : "Name",                        
                        "type" : "string"
                    }
                ],                
                "desc" : "\tSets the universe by name (if empty all interviews are selected)",                
                "examples" : [
                    "\tDim TabDef1 as TabDef",                    
                    "\tTabDef1.SetUniverse(\"Males\")"
                ],                
                "version" : "5.6.0.0"
            },            
            {
                "name" : "SetUniverse",                
                "ns" : "autoanalyselanguage",                
                "base" : "method",                
                "type" : "tabdef",                
                "args" : [
                    {
                        "name" : "UniverseID",                        
                        "type" : "number"
                    }
                ],                
                "desc" : [
                    "\tSets the universe by specifiying its id",                    
                    "\tHere are the preset universe ids",                    
                    "\tSP_ALLINTERVIEWS\t\t\t\t\t-1",                    
                    "\tUNI_SELECTED_RESPONSES\t\t\t\t-2",                    
                    "\tUNI_QUESTION_BASE\t\t\t\t\t-3",                    
                    "\tUNI_ANSWERING_FREQUENCY\t\t\t\t-4",                    
                    "\tUNI_CURRENT_SUBPOPULATION\t\t\t-5",                    
                    "\tUNI_UNFILTERED_SELECTED_RESPONSE\t-6",                    
                    "\tUNI_UNFILTERED_QUESTION_BASE\t\t-7",                    
                    "\tUNI_UNFILTERED_ANSWERING_FREQUENCY\t-8",                    
                    "\tSP_NO_INTERVIEW\t\t\t\t\t\t-9",                    
                    "\tUNI_QUESTION_TABLE_BASE\t\t\t\t-11",                    
                    "\tUNI_ALL_INTERVIEWS_TABLE\t\t\t-12"
                ],                
                "examples" : [
                    "\tDim TabDef1 as TabDef",                    
                    "\tTabDef1.SetUniverse(-2)"
                ],                
                "version" : "5.6.0.0"
            },            
            {
                "name" : "SetWeighting",                
                "ns" : "autoanalyselanguage",                
                "base" : "method",                
                "type" : "tabdef",                
                "args" : [
                    {
                        "name" : "Name",                        
                        "type" : "string"
                    }
                ],                
                "desc" : "\tSets the weighing by name (if empty \"No weighting\" is selected)",                
                "examples" : [
                    "\tDim TabDef1 as TabDef",                    
                    "\tTabDef1.SetWeighting(\"NatRep\")"
                ],                
                "version" : "5.6.1.0"
            },            
            {
                "name" : "SetWeighting",                
                "ns" : "autoanalyselanguage",                
                "base" : "method",                
                "type" : "tabdef",                
                "args" : [
                    {
                        "name" : "Weight",                        
                        "type" : "weighting"
                    }
                ],                
                "desc" : "\tSets the weighting by object (if the weighting is not saved, \"No weighting\" is selected)",                
                "examples" : [
                    "\tDim TabDef1 as TabDef",                    
                    "\tDim Weight as Weighting",                    
                    "\tTabDef1.SetWeighting(Weight)"
                ],                
                "version" : "5.6.1.0"
            },            
            {
                "name" : "Title",                
                "ns" : "autoanalyselanguage",                
                "base" : "property",                
                "type" : "string",                
                "desc" : "\tSets or returns the title of a cross tab def",                
                "examples" : [
                    "\tdim myGroup As TabDef",                    
                    "\tmyGroup.Title = \"??R?? x ??C??\""
                ],                
                "version" : "5.6.0.0"
            },            
            {
                "name" : "Weighting",                
                "ns" : "autoanalyselanguage",                
                "base" : "property",                
                "type" : "string",                
                "desc" : "\tSets or returns the name of the weighting used in the TabDef. If the string is empty, the weighing is \"No weighting\"",                
                "examples" : "\tmyTabDef.Weighting =\"NatRep\"",                
                "version" : "5.5.3.0"
            }
        ],        
        "calcvar" : [
            {
                "name" : "Add",                
                "ns" : "autoanalyselanguage",                
                "base" : "method",                
                "type" : "calcvar",                
                "args" : [
                    {
                        "name" : "Item",                        
                        "type" : "calcvarresponse"
                    },                    
                    {
                        "name" : "After",                        
                        "type" : "calcvarresponse",                        
                        "desc" : "After this item",                        
                        "opt" : true
                    }
                ],                
                "desc" : "\tAdds a profile item to a profile question",                
                "examples" : [
                    "\tDim myVar As CalcVar",                    
                    "",                    
                    "\tDim Resp1 as CalcVarResponse",                    
                    "\tResp1.Caption = \"ABC\"",                    
                    "\tResp1.Script = \"True\"",                    
                    "\tmyVar.Add(Resp1)",                    
                    "",                    
                    "\tDim Resp2 as CalcVarResponse",                    
                    "\tResp2.Caption = \"DEF\"",                    
                    "\tResp2.Script = \"False\"",                    
                    "\tmyVar.Add(Resp2, Resp1)"
                ],                
                "version" : "5.6.1.0"
            },            
            {
                "name" : "Caption",                
                "ns" : "autoanalyselanguage",                
                "base" : "property",                
                "type" : "string",                
                "desc" : "\tSets or returns the caption of a calculated question",                
                "examples" : [
                    "\tdim myVar As CalcVar",                    
                    "\tmyVar.Shortcut = \"NewAge\"",                    
                    "\tmyVar.Caption = \"Age shown in intervals\""
                ],                
                "version" : "5.6.1.0"
            },            
            {
                "name" : "Clear",                
                "ns" : "autoanalyselanguage",                
                "base" : "method",                
                "type" : "calcvar",                
                "desc" : "\tRemoves all the responses from the question",                
                "examples" : "\tmyVar.Clear()",                
                "version" : "5.6.1.0"
            },            
            {
                "name" : "Level",                
                "ns" : "autoanalyselanguage",                
                "base" : "property",                
                "type" : "string",                
                "desc" : "\tSets or returns the name of the level used in the calculated questions. The level is identified by the shortcut of the level. If the string is empty, the level is \"Interviews\"",                
                "examples" : [
                    "\tDim myVar As CalcVar",                    
                    "\tmyVar.Level =\"PeopleInHouseHold\""
                ],                
                "version" : "5.6.1.0"
            },            
            {
                "name" : "Read",                
                "ns" : "autoanalyselanguage",                
                "base" : "method",                
                "type" : "methodresult",                
                "args" : [
                    {
                        "name" : "Indicates",                        
                        "type" : "string",                        
                        "desc" : "the shortcut"
                    }
                ],                
                "desc" : "\topens a calculated variable",                
                "examples" : [
                    "\tDim myVar as CalcVar",                    
                    "\tDim res = myVar.Read(\"MyCalcVar\")",                    
                    "\treturn res.Success"
                ],                
                "version" : "5.6.1.0"
            },            
            {
                "name" : "Response",                
                "ns" : "autoanalyselanguage",                
                "base" : "property",                
                "type" : "calcvarresponses",                
                "desc" : "\tGets the list of closed responses for a calculated variable",                
                "examples" : [
                    "\tDim myV As CalcVar",                    
                    "",                    
                    "\tmyC.Shortcut = \"ABC\"",                    
                    "\tmyV.Type = 3",                    
                    "",                    
                    "\tDim Resp1 as CalcVarResponse",                    
                    "\tResp1.Caption = \"Yes\"",                    
                    "\tResp1.Script = \"True\"",                    
                    "\tmyV.Responses.Add(Resp1)"
                ],                
                "version" : "5.6.1.0"
            },            
            {
                "name" : "Save",                
                "ns" : "autoanalyselanguage",                
                "base" : "method",                
                "type" : "methodresult",                
                "desc" : "\tSaves a calculated variable in the survey",                
                "examples" : [
                    "\tDim myVar as CalcVar",                    
                    "\tmyVar.Shortcut =\"New Var\"",                    
                    "\tmyVar.Type = 1",                    
                    "\tmyVar.Script =\"Age.Value / Weight.Value\"",                    
                    "\tDim res = myVar.Save()",                    
                    "\treturn res.Success"
                ],                
                "version" : "5.6.1.0"
            },            
            {
                "name" : "Script",                
                "ns" : "autoanalyselanguage",                
                "base" : "property",                
                "type" : "string",                
                "desc" : "\tSets or returns the script for a calculated question",                
                "examples" : [
                    "\tdim myVar As CalcVar",                    
                    "\tmyVar.Caption = \"Top 2\"",                    
                    "\tmyVar.Script = \"Rating Has {1;2}\""
                ],                
                "version" : "5.6.1.0"
            },            
            {
                "name" : "SetSubPopulation",                
                "ns" : "autoanalyselanguage",                
                "base" : "method",                
                "type" : "calcvar",                
                "args" : [
                    {
                        "name" : "Name",                        
                        "type" : "string"
                    }
                ],                
                "desc" : "\tSets the sub-population by name (if empty all interviews are selected)",                
                "examples" : [
                    "\tDim R1 as CalcVar",                    
                    "\tR1.SetSubPopulation(\"Males\")"
                ],                
                "version" : "5.6.1.0"
            },            
            {
                "name" : "SetSubPopulation",                
                "ns" : "autoanalyselanguage",                
                "base" : "method",                
                "type" : "calcvar",                
                "args" : [
                    {
                        "name" : "SP",                        
                        "type" : "subpopulation"
                    }
                ],                
                "desc" : "\tSets the sub-population by object (if the SP is not saved, then the sub-population is \"all interviews\")",                
                "examples" : [
                    "\tDim R2 as CalcVar",                    
                    "\tDim Sp as SubPopulation",                    
                    "\tR2.SetSubPopulation(Sp)"
                ],                
                "version" : "5.6.1.0"
            },            
            {
                "name" : "Shortcut",                
                "ns" : "autoanalyselanguage",                
                "base" : "property",                
                "type" : "string",                
                "desc" : "\tSets or returns the shortcut of a calculated question",                
                "examples" : [
                    "\tdim myVar As CalcVar",                    
                    "\tmyVar.Shortcut = \"New-age\""
                ],                
                "version" : "5.6.1.0"
            },            
            {
                "name" : "Type",                
                "ns" : "autoanalyselanguage",                
                "base" : "property",                
                "type" : "number",                
                "desc" : [
                    "\tSets or returns the type of a calculated question",                    
                    "\t1: numeric by script",                    
                    "\t2: closed with scripts",                    
                    "\t3: closed with one single script",                    
                    "\t4: closed by finding all values of the script",                    
                    "\t5: numeric using weighting (specify the name in the Script property)",                    
                    "\t6: open by script"
                ],                
                "examples" : [
                    "\tdim myVar As CalcVar",                    
                    "\tmyVar.Shortcut = \"AllComments\"",                    
                    "\tmyVar.Script= \"qComments.Value\"",                    
                    "\tmyVar.Type = 4"
                ],                
                "version" : "5.6.1.0"
            }
        ],        
        "calcvarresponse" : [
            {
                "name" : "Caption",                
                "ns" : "autoanalyselanguage",                
                "base" : "property",                
                "type" : "string",                
                "desc" : "\tSets or returns the caption of a response for a calculated question",                
                "examples" : [
                    "\tdim myVar As CalcVarResponse",                    
                    "\tmyVar.Caption = \"Top 2\""
                ],                
                "version" : "5.6.1.0"
            },            
            {
                "name" : "Script",                
                "ns" : "autoanalyselanguage",                
                "base" : "property",                
                "type" : "string",                
                "desc" : "\tSets or returns the script for a response of a calculated question",                
                "examples" : [
                    "\tdim myVar As CalcVarResponse",                    
                    "\tmyVar.Caption = \"Top 2\"",                    
                    "\tmyVar.Script = \"Rating Has {1;2}\""
                ],                
                "version" : "5.6.1.0"
            }
        ],        
        "portfolio" : [
            {
                "name" : "Add",                
                "ns" : "autoanalyselanguage",                
                "base" : "method",                
                "type" : "portfolio",                
                "args" : [
                    {
                        "name" : "Item",                        
                        "type" : "portfolioitem",                        
                        "desc" : "Adds a portfolio item"
                    },                    
                    {
                        "name" : "Parent",                        
                        "type" : "portfolioitem",                        
                        "desc" : "As a child of this item",                        
                        "opt" : true
                    },                    
                    {
                        "name" : "After",                        
                        "type" : "portfolioitem",                        
                        "desc" : "After this item",                        
                        "opt" : true
                    }
                ],                
                "desc" : "\tAdds an item to a portfolio",                
                "examples" : [
                    "\tDim myPortfolio as Portfolio",                    
                    "\tDim myItem as PortfolioItem",                    
                    "\tmyPortfolio.Add(myItem)"
                ],                
                "version" : "5.5.2.0"
            },            
            {
                "name" : "Items",                
                "ns" : "autoanalyselanguage",                
                "base" : "property",                
                "type" : "portfolioitems",                
                "desc" : "\tReturns the list of portfolio items",                
                "version" : "5.5.2.0"
            },            
            {
                "name" : "Open",                
                "ns" : "autoanalyselanguage",                
                "base" : "method",                
                "type" : "portfolio",                
                "desc" : "\topens a portfolio",                
                "examples" : [
                    "\tDim myPortfolio as Portfolio",                    
                    "\tmyPortfolio.Read(\"Example.xml\")",                    
                    "\tmyPortfolio.Open()"
                ],                
                "version" : "5.5.2.0"
            },            
            {
                "name" : "Read",                
                "ns" : "autoanalyselanguage",                
                "base" : "method",                
                "type" : "methodresult",                
                "args" : [
                    {
                        "name" : "Path",                        
                        "type" : "string",                        
                        "desc" : "indicates the path"
                    },                    
                    {
                        "name" : "IsForClones",                        
                        "type" : "boolean",                        
                        "desc" : "to indicate if it's for cloning (then the questions do not have to exist in the survey to be read)"
                    }
                ],                
                "desc" : "\tReads a portfolio definition from a file",                
                "examples" : [
                    "\tDim myPortfolio as Portfolio",                    
                    "\tDim res = myPortfolio.Read(\"C:\\MyPortfolios\\definition.xml\",False)",                    
                    "\treturn res.Success"
                ],                
                "version" : "5.5.2.0"
            },            
            {
                "name" : "Remove",                
                "ns" : "autoanalyselanguage",                
                "base" : "method",                
                "type" : "portfolio",                
                "args" : [
                    {
                        "name" : "Item",                        
                        "type" : "portfolioitem",                        
                        "desc" : "to be removed"
                    }
                ],                
                "desc" : "\tRemoves an item from a portfolio",                
                "examples" : [
                    "\tDim myPortfolio as Portfolio",                    
                    "\tDim myItem as PortfolioItem",                    
                    "\tmyPortfolio.Remove(myItem)"
                ],                
                "version" : "5.6.1.0"
            },            
            {
                "name" : "Save",                
                "ns" : "autoanalyselanguage",                
                "base" : "method",                
                "type" : "methodresult",                
                "args" : [
                    {
                        "name" : "Path",                        
                        "type" : "string",                        
                        "desc" : "indicates the path"
                    }
                ],                
                "desc" : "\tSaves a portfolio definition to a file",                
                "examples" : [
                    "\tDim myPortfolio as Portfolio",                    
                    "\tDim res = myPortfolio.Read(\"C:\\MyPortfolios\\definition.xml\")",                    
                    "\tres = myPortfolio.Save(\"C:\\MyPortfolios\\NewDefinition.xml\")",                    
                    "\treturn res.Success"
                ],                
                "version" : "5.5.2.0"
            },            
            {
                "name" : "SetSubPopulation",                
                "ns" : "autoanalyselanguage",                
                "base" : "method",                
                "type" : "portfolio",                
                "args" : [
                    {
                        "name" : "Name",                        
                        "type" : "string"
                    }
                ],                
                "desc" : "\tSets the overall sub-population of a portfolio by name (if empty all interviews are selected)",                
                "examples" : [
                    "\tDim myPortfolio as Portfolio",                    
                    "\tmyPortfolio.SetSubPopulation(\"Males\")"
                ],                
                "version" : "5.6.0.0"
            },            
            {
                "name" : "SetSubPopulation",                
                "ns" : "autoanalyselanguage",                
                "base" : "method",                
                "type" : "portfolio",                
                "args" : [
                    {
                        "name" : "SP",                        
                        "type" : "string"
                    }
                ],                
                "desc" : "\tSets the overall sub-population of a portfolio by using an object",                
                "examples" : [
                    "\tDim myPortfolio as Portfolio",                    
                    "\tDim Sp as SubPopulation",                    
                    "\tmyPortfolio.SetSubPopulation(SP)"
                ],                
                "version" : "5.6.0.0"
            }
        ],        
        "portfolioitems" : [
            {
                "name" : "Count",                
                "ns" : "autoanalyselanguage",                
                "base" : "property",                
                "type" : "number",                
                "accessor" : "portfolioitem",                
                "desc" : "array of PortfolioItem",                
                "version" : "5.5.2.0"
            }
        ],        
        "calcvarresponses" : [
            {
                "ns" : "autoanalyselanguage",                
                "accessor" : "calcvarresponse",                
                "version" : "5.6.1.0"
            },            
            {
                "name" : "Count",                
                "ns" : "autoanalyselanguage",                
                "base" : "property",                
                "type" : "number",                
                "version" : "5.6.1.0"
            }
        ],        
        "survey" : [
            {
                "name" : "SandBox",                
                "ns" : "autoanalyselanguage",                
                "base" : "property",                
                "type" : "string",                
                "desc" : "\tReturns the directory where the output should take place. If the sand box is not specified (in the GUI), then the survey directory is used",                
                "examples" : "\tSurvey.SandBox ' => \"C:\\Qes\\ThisSurvey\\\"",                
                "version" : "5.6.1.0"
            }
        ]
    }
}, true);

});
